@@ -10,6 +10,7 @@ from typing import Dict, List, Optional
 
 from log_symbols import LogSymbols
 from packaging.version import parse
+from termcolor import colored
 from update_checker import UpdateChecker  # type: ignore
 
 from .cli_context import CLIContext
@@ -32,8 +33,6 @@ from ..models import (
     Query,
     HealthReportStatus,
     DEFAULT_LIMIT,
-    INF,
-    NEGATIVE_ONE,
     TimeGranularity,
 )
 from .. import PACKAGE_NAME, __version__
@@ -319,11 +318,6 @@ def query(
     allow_dynamic_cache: bool = True,
 ) -> None:
     """Create a new MQL query, polls for completion and assembles a DataFrame from the response."""
-    if not limit:
-        limit = DEFAULT_LIMIT
-    elif limit == INF:
-        limit = NEGATIVE_ONE
-
     validate_query_args(limit)
 
     # Note: calling config.resolve_query_model_key may initiate a dialog if the user has a pinned model
@@ -342,7 +336,7 @@ def query(
         time_granularity=time_granularity.value if time_granularity else None,
         time_comparison=time_comparison.value if time_comparison else None,
         order=order,
-        limit=limit,
+        limit=limit or DEFAULT_LIMIT,
         cache_mode=cache_mode.value if cache_mode else None,
         as_table=as_table,
         allow_dynamic_cache=allow_dynamic_cache,
@@ -826,6 +820,12 @@ def validate_configs(config: CLIContext, config_dir: str) -> None:
 @config_validation_options
 @click.option("--pin", type=bool, required=False, help="Whether to pin the model or not")
 @click.option("--force-primary", is_flag=True, default=None, help="Make this model current")
+@click.option(
+    "--dw-validations",
+    is_flag=True,
+    default=False,
+    help="Run data warehouse validations after model is successfully committed",
+)
 @pass_config
 @click.pass_context
 @exception_handler
@@ -835,6 +835,7 @@ def commit_configs(
     config_dir: str,
     pin: Optional[bool] = None,
     force_primary: Optional[bool] = None,
+    dw_validations: Optional[bool] = False,
 ) -> None:
     """Commit yaml configs found in specified config directory"""
     spinner = Halo(text="Parsing and uploading configs…", spinner="dots")
@@ -844,6 +845,16 @@ def commit_configs(
         f"🦄 Successfully committed configs id {model.id} on branch {model.branch} with commit {model.commit}"
     )
 
+    if dw_validations:
+        spinner_dw = Halo(text="Validating commited model against data warehouse", spinner="dots")
+        spinner_dw.start()
+        issues = config.mql.validate_model_against_data_warehouse(model.id)
+        if issues is not None and len(issues) == 0:
+            spinner_dw.succeed(f"🚀 Successfully validated model {model.id} against data warehouse, no issues found")
+        else:
+            spinner_dw.fail(f"❌ Issues found when validating model {model.id} against data warehouse")
+            print(colored("\n".join(issues), "red"))
+
     if pin is None:
         if click.confirm("📌 Would you like to pin this model commit for future MQL queries?"):
             pin = True
